@@ -41,6 +41,8 @@ sub new
   
   no strict 'refs';
   ${"$ClassName\::instance"} = $s;
+#  weaken($s);
+  return $s;
 }# end new()
 
 
@@ -63,9 +65,6 @@ sub setup_request
   
   $s->{connection}  = $s->r->connection;
   
-  $s->_load_class( $s->config->web->handler_resolver );
-  $s->{handler} = $s->config->web->handler_resolver->new()->resolve_request_handler( $s->r->uri );
-  
   if( ! $s->{parent} )
   {
     $s->{response} = Apache2::ASP::Response->new();
@@ -98,11 +97,22 @@ sub setup_request
     # Make the global Stash object:
     $s->{stash} = { };
     
-    $s->{global_asa} = $s->resolve_global_asa_class( );
-    $s->{global_asa}->init_asp_objects( $s )
-      unless $s->{handler}->isa('Apache2::ASP::UploadHandler');
   }# end if()
   
+  $s->_load_class( $s->config->web->handler_resolver );
+  eval {
+    $s->{handler} = $s->config->web->handler_resolver->new()->resolve_request_handler( $s->r->uri );
+  };
+  if( $@ )
+  {
+    $s->server->{LastError} = $@;
+    return $s->handle_error;
+  }# end if()
+
+  $s->{global_asa} = $s->resolve_global_asa_class( );
+  $s->{global_asa}->init_asp_objects( $s )
+    unless $s->{handler}->isa('Apache2::ASP::UploadHandler');
+  
   return 1;
 }# end setup_request()
 
@@ -257,7 +267,6 @@ sub do_preinit
 {
   my $s = shift;
   
-  
   unless( $s->_is_setup )
   {
     $s->setup_request( $Apache2::ASP::ModPerl::R, $Apache2::ASP::ModPerl::CGI );
@@ -478,6 +487,13 @@ sub AUTOLOAD
 sub DESTROY
 {
   my $s = shift;
+  
+  if( $s->{parent} )
+  {
+    no strict 'refs';
+    ${"$ClassName\::instance"} = delete($s->{parent});
+  }# end if()
+  
   undef(%$s);
 }# end DESTROY()
 
